fff

package
v0.0.30 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 14, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DeriveURL

func DeriveURL(domainRoot, filePath, domain string) string

DeriveURL constructs a URL from the fff root, file path, and domain.

func ParseFFF

func ParseFFF(ctx context.Context, root string, skipFunc func(string) bool, concurrency int) (<-chan *model.OfflineInput, error)

ParseFFF parses an fff directory structure and returns a channel of OfflineInput.

Types

This section is empty.

Jump to