progress

package
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 26, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Tracker

type Tracker struct {
	// contains filtered or unexported fields
}

Tracker manages and displays progress updates.

func NewTracker

func NewTracker(total uint32, quiet, colorize bool) *Tracker

NewTracker creates a new progress tracker.

func (*Tracker) AddTotal

func (t *Tracker) AddTotal(count uint32)

AddTotal atomically adds to the total count.

func (*Tracker) Clear

func (t *Tracker) Clear()

Clear clears the progress line.

func (*Tracker) Done

func (t *Tracker) Done()

Done marks the tracker as complete and prints final summary.

func (*Tracker) FinalizeTotal

func (t *Tracker) FinalizeTotal()

FinalizeTotal marks the discovery phase as complete.

func (*Tracker) Increment

func (t *Tracker) Increment()

Increment increments the completed count and prints progress if enabled.

func (*Tracker) IncrementError

func (t *Tracker) IncrementError()

IncrementError records a failed target.

func (*Tracker) IncrementSuccess

func (t *Tracker) IncrementSuccess()

IncrementSuccess records a successful scan.

func (*Tracker) Refresh

func (t *Tracker) Refresh()

Refresh re-prints the current progress line.

Jump to